==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/cabin2/dialogs_pl.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Okrrrutny, okrrrutny, okrrrutny kapitan Silverrrr...")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Okrrrutny kapitan Silverrrr...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("Kurrrczę!")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn`t it?")
dialogStr("Sprrrytny prrroblem, prrrawda?")


dialogId("k1-pap-sakris", "font_parrot", "Darrrn!")
dialogStr("Cholerrra!")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("Polly chce krrrakerrrsa!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Sfrrruwaj...")


dialogId("ka2-v-nekde", "font_big", "Didn`t we see this somewhere already?")
dialogStr("Już to chyba gdzieś widzieliśmy...")


dialogId("ka2-m-kdepak", "font_small", "No, you`re wrong. This cabin is one hundred and forty four squares larger...")
dialogStr("Mylisz się, ta kajuta jest o sto czterdzieści cztery pola większa...")


dialogId("ka2-v-papousek", "font_big", "Look at that parrot!!!")
dialogStr("Spójrz na tę papugę!!!")


dialogId("ka2-m-kostra", "font_small", "So what? It's a normal skeleton.")
dialogStr("No co, zwykły szkielet.")


dialogId("ka2-m-posledni", "font_small", "Can you see it? This room is almost the last in the row. Could this really be that treasure?")
dialogStr("To już prawie ostatnie pomieszczenie. Czy to może być skarb, którego szukamy?")


dialogId("ka2-v-mapa0", "font_big", "And what would be in the other two?")
dialogStr("A co by było w tych dwóch ostatnich?")


dialogId("ka2-v-mapa1", "font_big", "They told us clearly to find the map. Nobody mentioned treasure.")
dialogStr("Jasno nam powiedzieli, żebyśmy znaleźli mapę. Nikt nic nie mówił o skarbie.")


dialogId("ka2-v-mapa2", "font_big", "Don`t be so annoying. The authors of the game would surely let the player know.")
dialogStr("Nie podniecaj się tak, autorzy z pewnością nie trzymaliby gracza w niepewności!")


dialogId("ka2-m-chapadlo", "font_small", "This octopus has unpleasantly knotted tentacles. I can`t fit between them.")
dialogStr("Ta ośmiornica ma nieprzyjemnie splątane macki. Nie mogę się między nimi zmieścić.")


dialogId("ka2-v-fik", "font_big", "... so what if we cut one off?!")
dialogStr("... a może jej jedną obetniemy?!")


dialogId("ka2-v-napad", "font_big", "I am sorry, it was just an idea.")
dialogStr("Przepraszam, tak sobie tylko pomyślałem.")


dialogId("ka2-m-hej", "font_small", "Little octopus, couldn`t you move away a little bit, please?")
dialogStr("Hej, ośmiorniczko, nie mogłabyś się ciutkę przesunąć?")


dialogId("ka2-m-diky", "font_small", "Hmm... thanks a lot.")
dialogStr("Hmmm... dzięki.")


dialogId("ka2-v-kostry", "font_big", "Skeletons seem to be a favorite motif of this game authors.")
dialogStr("Szkielety są najwyraźniej ulubionym motywem twórców tej gry.")


dialogId("ka2-m-patrne", "font_small", "Who are probably living on land. These skeletons are visible proof of their effort to stuff the ocean with all the things that don`t belong there.")
dialogStr("To pewnie szczury lądowe. Te szkielety to namacalny dowód, że próbują zapełnić ocean rzeczami, które tu nie przynależą.")


dialogId("ka2-v-myslet", "font_big", "Let`s try to think. Can`t we take our solution of that previous cabin and modify it a little?")
dialogStr("Zastanówmy się. Nie dałoby się wziąć naszego rozwiązania z poprzedniej kajuty i nieco go zmodyfikować?")


dialogId("ka2-m-tezko", "font_small", "Hmm... I don`t think so.")
dialogStr("Hmmm... nie bardzo.")


dialogId("ka2-m-svitit", "font_small", "So, let`s shed some light on it.")
dialogStr("Przyświećmy sobie.")


dialogId("ka2-v-hrbet", "font_big", "My back aches.")
dialogStr("Już mnie grzbiet boli.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/cabin2/dialogs_pl.lua <==

dialogId("k1-pap-3xkruty", "font_parrot", "Crrruel, crrruel, crrruel Captain Silverrrr...")
dialogStr("Okrrrutny, okrrrutny, okrrrutny kapitan Silverrrr...")


dialogId("k1-pap-kruty", "font_parrot", "Crrruel Captain Silverrrr...")
dialogStr("Okrrrutny kapitan Silverrrr...")


dialogId("k1-pap-kruci", "font_parrot", "Good grrrief!")
dialogStr("Kurrrczę!")


dialogId("k1-pap-problem", "font_parrot", "Trrricky prrroblem, isn’t it?")
dialogStr("Sprrrytny prrroblem, prrrawda?")


dialogId("k1-pap-sakris", "font_parrot", "Darrrn!")
dialogStr("Cholerrra!")


dialogId("k1-pap-sucharek", "font_parrot", "Polly wants a crrracker!")
dialogStr("Polly chce krrrakerrrsa!")


dialogId("k1-pap-trhnisi", "font_parrot", "Beat it, sirrr...")
dialogStr("Sfrrruwaj...")


dialogId("ka2-v-nekde", "font_big", "Didn’t we see this somewhere already?")
dialogStr("Już to chyba gdzieś widzieliśmy...")


dialogId("ka2-m-kdepak", "font_small", "No, you’re wrong. This cabin is one hundred and forty four squares larger...")
dialogStr("Mylisz się, ta kajuta jest o sto czterdzieści cztery pola większa...")


dialogId("ka2-v-papousek", "font_big", "Look at that parrot!!!")
dialogStr("Spójrz na tę papugę!!!")


dialogId("ka2-m-kostra", "font_small", "So what? It's a normal skeleton.")
dialogStr("No co, zwykły szkielet.")


dialogId("ka2-m-posledni", "font_small", "Can you see it? This room is almost the last in the row. Could this really be that treasure?")
dialogStr("To już prawie ostatnie pomieszczenie. Czy to może być skarb, którego szukamy?")


dialogId("ka2-v-mapa0", "font_big", "And what would be in the other two?")
dialogStr("A co by było w tych dwóch ostatnich?")


dialogId("ka2-v-mapa1", "font_big", "They told us clearly to find the map. Nobody mentioned treasure.")
dialogStr("Jasno nam powiedzieli, żebyśmy znaleźli mapę. Nikt nic nie mówił o skarbie.")


dialogId("ka2-v-mapa2", "font_big", "Don’t be so annoying. The authors of the game would surely let the player know.")
dialogStr("Nie podniecaj się tak, autorzy z pewnością nie trzymaliby gracza w niepewności!")


dialogId("ka2-m-chapadlo", "font_small", "This octopus has unpleasantly knotted tentacles. I can’t fit between them.")
dialogStr("Ta ośmiornica ma nieprzyjemnie splątane macki. Nie mogę się między nimi zmieścić.")


dialogId("ka2-v-fik", "font_big", "... so what if we cut one off?!")
dialogStr("... a może jej jedną obetniemy?!")


dialogId("ka2-v-napad", "font_big", "I am sorry, it was just an idea.")
dialogStr("Przepraszam, tak sobie tylko pomyślałem.")


dialogId("ka2-m-hej", "font_small", "Little octopus, couldn’t you move away a little bit, please?")
dialogStr("Hej, ośmiorniczko, nie mogłabyś się ciutkę przesunąć?")


dialogId("ka2-m-diky", "font_small", "Hmm... thanks a lot.")
dialogStr("Hmmm... dzięki.")


dialogId("ka2-v-kostry", "font_big", "Skeletons seem to be a favorite motif of this game authors.")
dialogStr("Szkielety są najwyraźniej ulubionym motywem twórców tej gry.")


dialogId("ka2-m-patrne", "font_small", "Who are probably living on land. These skeletons are visible proof of their effort to stuff the ocean with all the things that don’t belong there.")
dialogStr("To pewnie szczury lądowe. Te szkielety to namacalny dowód, że próbują zapełnić ocean rzeczami, które tu nie przynależą.")


dialogId("ka2-v-myslet", "font_big", "Let’s try to think. Can’t we take our solution of that previous cabin and modify it a little?")
dialogStr("Zastanówmy się. Nie dałoby się wziąć naszego rozwiązania z poprzedniej kajuty i nieco go zmodyfikować?")


dialogId("ka2-m-tezko", "font_small", "Hmm... I don’t think so.")
dialogStr("Hmmm... nie bardzo.")


dialogId("ka2-m-svitit", "font_small", "So, let’s shed some light on it.")
dialogStr("Przyświećmy sobie.")


dialogId("ka2-v-hrbet", "font_big", "My back aches.")
dialogStr("Już mnie grzbiet boli.")
